@@ -1,12 +1,21 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
+from enum import Enum
+
 import attr
 
 from mozanalysis.bq import sanitize_table_name_for_bq
 from mozanalysis.utils import add_days, date_sub, hash_ish
 
 
+class AnalysisBasis(Enum):
+    """Determines what the population used for the analysis will be based on."""
+
+    ENROLLMENTS = "enrollments"
+    EXPOSURES = "exposures"
+
+
 @attr.s(frozen=True, slots=True)
 class Experiment:
     """Query experiment data; store experiment metadata.
@@ -116,6 +125,8 @@ class Experiment:
         analysis_length_days,
         enrollments_query_type="normandy",
         custom_enrollments_query=None,
+        custom_exposure_query=None,
+        exposure_signal=None,
         segment_list=None,
     ):
         """Return a DataFrame containing per-client metric values.
@@ -150,6 +161,20 @@ class Experiment:
                 (client_id, branch), or else your results will be subtly
                 wrong.
 
+            custom_exposure_query (str): A full SQL query to be used in the main
+                query::
+
+                    WITH ...
+                    exposures AS ({custom_exposure_query})
+
+                If not provided, the exposure will be determined based on
+                `exposure_signal`, if provided, or Normandy and Nimbus exposure events.
+                `custom_exposure_query` takes precedence over `exposure_signal`.
+
+            exposure_signal (ExposureSignal): Optional signal definition of when a
+                client has been exposed to the experiment. If not provided,
+                the exposure will be determined based on Normandy exposure events
+                for desktop and Nimbus exposure events for Fenix and iOS.
             segment_list (list of mozanalysis.segment.Segment): The user
                 segments to study.
 
@@ -192,6 +217,8 @@ class Experiment:
             time_limits=time_limits,
             enrollments_query_type=enrollments_query_type,
             custom_enrollments_query=custom_enrollments_query,
+            custom_exposure_query=custom_exposure_query,
+            exposure_signal=exposure_signal,
             segment_list=segment_list,
         )
 
@@ -230,6 +257,8 @@ class Experiment:
         time_series_period="weekly",
         enrollments_query_type="normandy",
         custom_enrollments_query=None,
+        custom_exposure_query=None,
+        exposure_signal=None,
         segment_list=None,
     ):
         """Return a TimeSeriesResult with per-client metric values.
@@ -260,6 +289,20 @@ class Experiment:
                 (client_id, branch), or else your results will be subtly
                 wrong.
 
+            custom_exposure_query (str): A full SQL query to be used in the main
+                query::
+
+                    WITH ...
+                    exposures AS ({custom_exposure_query})
+
+                If not provided, the exposure will be determined based on
+                `exposure_signal`, if provided, or Normandy and Nimbus exposure events.
+                `custom_exposure_query` takes precedence over `exposure_signal`.
+
+            exposure_signal (ExposureSignal): Optional signal definition of when a
+                client has been exposed to the experiment. If not provided,
+                the exposure will be determined based on Normandy exposure events
+                for desktop and Nimbus exposure events for Fenix and iOS.
             segment_list (list of mozanalysis.segment.Segment): The user
                 segments to study.
 
@@ -299,6 +342,8 @@ class Experiment:
             time_limits=time_limits,
             enrollments_query_type=enrollments_query_type,
             custom_enrollments_query=custom_enrollments_query,
+            custom_exposure_query=custom_exposure_query,
+            exposure_signal=exposure_signal,
             segment_list=segment_list,
         )
 
@@ -341,9 +386,11 @@ class Experiment:
         time_limits,
         enrollments_query_type="normandy",
         custom_enrollments_query=None,
+        custom_exposure_query=None,
+        exposure_signal=None,
         segment_list=None,
     ) -> str:
-        """Return a SQL query for querying enrollments data.
+        """Return a SQL query for querying enrollment and exposure data.
 
         Args:
             time_limits (TimeLimits): An object describing the
@@ -356,6 +403,14 @@ class Experiment:
                 in the main query::
 
                     WITH raw_enrollments AS ({custom_enrollments_query})
+            custom_exposure_query (str): A full SQL query to be used in the main
+                query::
+
+                    WITH ...
+                    exposures AS ({custom_exposure_query})
+
+            exposure_signal (ExposureSignal): Optional signal definition of when a
+                client has been exposed to the experiment
 
             segment_list (list of mozanalysis.segment.Segment): The user
                 segments to study.
@@ -367,17 +422,32 @@ class Experiment:
             time_limits, enrollments_query_type
         )
 
+        if exposure_signal:
+            exposure_query = custom_exposure_query or exposure_signal.build_query(
+                time_limits
+            )
+        else:
+            exposure_query = custom_exposure_query or self._build_exposure_query(
+                time_limits, enrollments_query_type
+            )
+
         segments_query = self._build_segments_query(segment_list, time_limits)
 
         return """
             WITH raw_enrollments AS ({enrollments_query}),
-            segmented_enrollments AS ({segments_query})
+            segmented_enrollments AS ({segments_query}),
+            exposures AS ({exposure_query})
 
-            SELECT se.*
+            SELECT
+                se.*,
+                e.* EXCEPT (client_id, branch)
             FROM segmented_enrollments se
+            LEFT JOIN exposures e
+            USING (client_id, branch)
         """.format(
             enrollments_query=enrollments_query,
             segments_query=segments_query,
+            exposure_query=exposure_query,
         )
 
     def build_metrics_query(
@@ -385,6 +455,7 @@ class Experiment:
         metric_list,
         time_limits,
         enrollments_table,
+        analysis_basis=AnalysisBasis.ENROLLMENTS,
     ) -> str:
         """Return a SQL query for querying metric data.
 
@@ -399,6 +470,8 @@ class Experiment:
             time_limits (TimeLimits): An object describing the
                 interval(s) to query
             enrollments_table (str): The name of the enrollments table
+            basis (AnalysisBasis): Use exposures as basis for calculating
+                metrics if True, otherwise use enrollments.
 
         Returns:
             A string containing a BigQuery SQL expression.
@@ -410,7 +483,7 @@ class Experiment:
         )
 
         metrics_columns, metrics_joins = self._build_metrics_query_bits(
-            metric_list, time_limits
+            metric_list, time_limits, analysis_basis
         )
 
         return """
@@ -469,6 +542,23 @@ class Experiment:
         else:
             raise ValueError
 
+    def _build_exposure_query(self, time_limits, exposure_query_type):
+        """Return SQL to query a list of exposures and their branches"""
+        if exposure_query_type == "normandy":
+            return self._build_exposure_query_normandy(time_limits)
+        elif exposure_query_type == "glean-event":
+            if not self.app_id:
+                raise ValueError(
+                    "App ID must be defined for building Glean enrollments query"
+                )
+            return self._build_exposure_query_glean_event(time_limits, self.app_id)
+        elif exposure_query_type == "fenix-fallback":
+            return self._build_exposure_query_glean_event(
+                time_limits, "org_mozilla_firefox"
+            )
+        else:
+            raise ValueError
+
     def _build_enrollments_query_normandy(self, time_limits):
         """Return SQL to query enrollments for a normandy experiment"""
         return """
@@ -476,8 +566,8 @@ class Experiment:
             e.client_id,
             `mozfun.map.get_key`(e.event_map_values, 'branch')
                 AS branch,
-            min(e.submission_date) AS enrollment_date,
-            count(e.submission_date) AS num_enrollment_events
+            MIN(e.submission_date) AS enrollment_date,
+            COUNT(e.submission_date) AS num_enrollment_events
         FROM
             `moz-fx-data-shared-prod.telemetry.events` e
         WHERE
@@ -511,9 +601,11 @@ class Experiment:
                 b.ping_info.experiments,
                 '{experiment_slug}'
             ).branch,
-            DATE(MIN(b.submission_timestamp)) AS enrollment_date
+            DATE(MIN(b.submission_timestamp)) AS enrollment_date,
+            COUNT(b.submission_date) AS num_enrollment_events
         FROM `moz-fx-data-shared-prod.{dataset}.baseline` b
         WHERE
+            b.client_info.client_id IS NOT NULL AND
             DATE(b.submission_timestamp)
                 BETWEEN DATE_SUB('{first_enrollment_date}', INTERVAL 7 DAY)
                 AND '{last_enrollment_date}'
@@ -546,10 +638,12 @@ class Experiment:
                     e.extra,
                     'branch'
                 ) AS branch,
-                DATE(MIN(events.submission_timestamp)) AS enrollment_date
+                DATE(MIN(events.submission_timestamp)) AS enrollment_date,
+                COUNT(events.submission_timestamp) AS num_enrollment_events
             FROM `moz-fx-data-shared-prod.{dataset}.events` events,
             UNNEST(events.events) AS e
             WHERE
+                events.client_info.client_id IS NOT NULL AND
                 DATE(events.submission_timestamp)
                 BETWEEN '{first_enrollment_date}' AND '{last_enrollment_date}'
                 AND e.category = "nimbus_events"
@@ -563,7 +657,79 @@ class Experiment:
             dataset=self.app_id or dataset,
         )
 
-    def _build_metrics_query_bits(self, metric_list, time_limits):
+    def _build_exposure_query_normandy(self, time_limits):
+        """Return SQL to query exposures for a normandy experiment"""
+        return """
+        SELECT
+            e.client_id,
+            e.branch,
+            min(e.submission_date) AS exposure_date,
+            COUNT(e.submission_date) AS num_exposure_events
+        FROM raw_enrollments re
+        LEFT JOIN (
+            SELECT
+                client_id,
+                `mozfun.map.get_key`(event_map_values, 'branch') AS branch,
+                submission_date
+            FROM
+                `moz-fx-data-shared-prod.telemetry.events`
+            WHERE
+                event_category = 'normandy'
+                AND (event_method = 'exposure' AND event_method = 'expose')
+                AND submission_date
+                    BETWEEN '{first_enrollment_date}' AND '{last_enrollment_date}'
+                AND event_string_value = '{experiment_slug}'
+        ) e
+        ON re.client_id = e.client_id AND
+            re.branch = e.branch AND
+            e.submission_date >= re.enrollment_date
+        GROUP BY e.client_id, e.branch
+            """.format(
+            experiment_slug=self.experiment_slug,
+            first_enrollment_date=time_limits.first_enrollment_date,
+            last_enrollment_date=time_limits.last_enrollment_date,
+        )
+
+    def _build_exposure_query_glean_event(self, time_limits, dataset):
+        """Return SQL to query exposures for a Glean no-event experiment"""
+        return """
+            SELECT
+                exposures.client_id,
+                exposures.branch,
+                DATE(MIN(exposures.submission_date)) AS exposure_date,
+                COUNT(exposures.submission_date) AS num_exposure_events
+            FROM raw_enrollments re
+            LEFT JOIN (
+                SELECT
+                    client_info.client_id,
+                    `mozfun.map.get_key`(event.extra, 'branch') AS branch,
+                    DATE(events.submission_timestamp) AS submission_date
+                FROM
+                    `moz-fx-data-shared-prod.{dataset}.events` events,
+                    UNNEST(events.events) AS event
+                WHERE
+                    DATE(events.submission_timestamp)
+                    BETWEEN '{first_enrollment_date}' AND '{last_enrollment_date}'
+                    AND event.category = "nimbus_events"
+                    AND mozfun.map.get_key(
+                        event.extra,
+                        "experiment") = '{experiment_slug}'
+                    AND (event.name = 'expose' OR event.name = 'exposure')
+            ) exposures
+            ON re.client_id = exposures.client_id AND
+                re.branch = exposures.branch AND
+                exposures.submission_date >= re.enrollment_date
+            GROUP BY client_id, branch
+            """.format(
+            experiment_slug=self.experiment_slug,
+            first_enrollment_date=time_limits.first_enrollment_date,
+            last_enrollment_date=time_limits.last_enrollment_date,
+            dataset=self.app_id or dataset,
+        )
+
+    def _build_metrics_query_bits(
+        self, metric_list, time_limits, analysis_basis=AnalysisBasis.ENROLLMENTS
+    ):
         """Return lists of SQL fragments corresponding to metrics."""
         ds_metrics = self._partition_by_data_source(metric_list)
         ds_metrics = {
@@ -576,7 +742,11 @@ class Experiment:
 
         for i, ds in enumerate(ds_metrics.keys()):
             query_for_metrics = ds.build_query(
-                ds_metrics[ds], time_limits, self.experiment_slug, self.app_id
+                ds_metrics[ds],
+                time_limits,
+                self.experiment_slug,
+                self.app_id,
+                analysis_basis,
             )
             metrics_joins.append(
                 """    LEFT JOIN (
